@@ -258,7 +258,7 @@ class Sphinx(object):
             for catinfo in find_catalog_source_files(
                     user_locale_dirs, self.config.language, domains=['sphinx'],
                     charset=self.config.source_encoding):
-                catinfo.write_mo(self.config.language)
+                catinfo.write_mo(self.config.language, self.warn)
             locale_dirs = [None, path.join(package_dir, 'locale')] + user_locale_dirs
         else:
             locale_dirs = []
@@ -484,7 +484,7 @@ class Sphinx(object):
         summary = bold(summary)
         for item in iterable:
             l += 1
-            s = '%s[%3d%%] %s' % (summary, 100*l/length,
+            s = '%s[%3d%%] %s' % (summary, 100 * l / length,
                                   colorfunc(stringify_func(item)))
             if self.verbosity:
                 s += '\n'
@@ -660,9 +660,9 @@ class Sphinx(object):
             else:
                 # ignore invalid keys for compatibility
                 continue
-            setattr(translator, 'visit_'+node.__name__, visit)
+            setattr(translator, 'visit_' + node.__name__, visit)
             if depart:
-                setattr(translator, 'depart_'+node.__name__, depart)
+                setattr(translator, 'depart_' + node.__name__, depart)
 
     def add_enumerable_node(self, node, figtype, title_getter=None, **kwds):
         self.enumerable_nodes[node] = (figtype, title_getter)
@@ -806,7 +806,8 @@ class Sphinx(object):
 
     def add_latex_package(self, packagename, options=None):
         self.debug('[app] adding latex package: %r', packagename)
-        self.builder.usepackages.append((packagename, options))
+        if hasattr(self.builder, 'usepackages'):  # only for LaTeX builder
+            self.builder.usepackages.append((packagename, options))
 
     def add_lexer(self, alias, lexer):
         self.debug('[app] adding lexer: %r', (alias, lexer))
