@@ -160,3 +160,9 @@ class ReSTDomain(Domain):
 
 def setup(app):
     app.add_domain(ReSTDomain)
+
+    return {
+        'version': 'builtin',
+        'parallel_read_safe': True,
+        'parallel_write_safe': True,
+    }
