@@ -224,11 +224,11 @@ class Toctree(EnvironmentManager):
                 if isinstance(subnode, (addnodes.compact_paragraph,
                                         nodes.list_item)):
                     # for <p> and <li>, indicate the depth level and recurse
-                    subnode['classes'].append('toctree-l%d' % (depth-1))
+                    subnode['classes'].append('toctree-l%d' % (depth - 1))
                     _toctree_add_classes(subnode, depth)
                 elif isinstance(subnode, nodes.bullet_list):
                     # for <ul>, just recurse
-                    _toctree_add_classes(subnode, depth+1)
+                    _toctree_add_classes(subnode, depth + 1)
                 elif isinstance(subnode, nodes.reference):
                     # for <a>, identify which entries point to the current
                     # document and therefore may not be collapsed
@@ -270,7 +270,7 @@ class Toctree(EnvironmentManager):
                         # toctree originates
                         ref = toctreenode['parent']
                         if not title:
-                            title = clean_astext(self.titles[ref])
+                            title = clean_astext(self.env.titles[ref])
                         reference = nodes.reference('', '', internal=True,
                                                     refuri=ref,
                                                     anchorname='',
@@ -417,7 +417,7 @@ class Toctree(EnvironmentManager):
                         subnode.parent.remove(subnode)
                     else:
                         # recurse on visible children
-                        self._toctree_prune(subnode, depth+1, maxdepth,  collapse)
+                        self._toctree_prune(subnode, depth + 1, maxdepth, collapse)
 
     def assign_section_numbers(self):
         """Assign a section number to each heading under a numbered toctree."""
@@ -434,7 +434,7 @@ class Toctree(EnvironmentManager):
             for subnode in node.children:
                 if isinstance(subnode, nodes.bullet_list):
                     numstack.append(0)
-                    _walk_toc(subnode, secnums, depth-1, titlenode)
+                    _walk_toc(subnode, secnums, depth - 1, titlenode)
                     numstack.pop()
                     titlenode = None
                 elif isinstance(subnode, nodes.list_item):
@@ -464,10 +464,14 @@ class Toctree(EnvironmentManager):
             if depth == 0:
                 return
             for (title, ref) in toctreenode['entries']:
-                if url_re.match(ref) or ref == 'self' or ref in assigned:
+                if url_re.match(ref) or ref == 'self':
                     # don't mess with those
                     continue
-                if ref in self.tocs:
+                elif ref in assigned:
+                    self.env.warn_node('%s is already assigned section numbers '
+                                       '(nested numbered toctree?)' % ref,
+                                       toctreenode, type='toc', subtype='secnum')
+                elif ref in self.tocs:
                     secnums = self.toc_secnumbers[ref] = {}
                     assigned.add(ref)
                     _walk_toc(self.tocs[ref], secnums, depth,
