@@ -5,7 +5,7 @@
 
     Parallel building utilities.
 
-    :copyright: Copyright 2007-2015 by the Sphinx team, see AUTHORS.
+    :copyright: Copyright 2007-2016 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
@@ -73,7 +73,8 @@ class ParallelTasks(object):
                 ret = func(arg)
             pipe.send((False, ret))
         except BaseException as err:
-            pipe.send((True, (err, traceback.format_exc())))
+            errmsg = traceback.format_exception_only(err.__class__, err)[0].strip()
+            pipe.send((True, (errmsg, traceback.format_exc())))
 
     def add_task(self, task_func, arg=None, result_func=None):
         tid = self._taskid
@@ -116,11 +117,11 @@ def make_chunks(arguments, nproc, maxbatch=10):
     chunksize = nargs // nproc
     if chunksize >= maxbatch:
         # try to improve batch size vs. number of batches
-        chunksize = int(sqrt(nargs/nproc * maxbatch))
+        chunksize = int(sqrt(nargs / nproc * maxbatch))
     if chunksize == 0:
         chunksize = 1
     nchunks, rest = divmod(nargs, chunksize)
     if rest:
         nchunks += 1
     # partition documents in "chunks" that will be written by one Process
-    return [arguments[i*chunksize:(i+1)*chunksize] for i in range(nchunks)]
+    return [arguments[i * chunksize:(i + 1) * chunksize] for i in range(nchunks)]
