@@ -50,15 +50,14 @@ DEFAULT_SETTINGS = {
     'latex_engine':    'pdflatex',
     'papersize':       'letterpaper',
     'pointsize':       '10pt',
-    'pxunit':          '49336sp',
+    'pxunit':          '.75bp',
     'classoptions':    '',
     'extraclassoptions': '',
     'maxlistdepth':    '',
     'sphinxpkgoptions':     '',
     'sphinxsetup':     '',
     'passoptionstopackages': '',
-    'geometry':       ('\\usepackage[margin=1in,marginparwidth=0.5in]'
-                       '{geometry}'),
+    'geometry':        '\\usepackage{geometry}',
     'inputenc':        '',
     'utf8extra':       '',
     'cmappkg':         '\\usepackage{cmap}',
@@ -85,7 +84,7 @@ DEFAULT_SETTINGS = {
     'release':         '',
     'author':          '',
     'logo':            '',
-    'releasename':     'Release',
+    'releasename':     '',
     'makeindex':       '\\makeindex',
     'shorthandoff':    '',
     'maketitle':       '\\maketitle',
@@ -122,8 +121,7 @@ ADDITIONAL_SETTINGS = {
     },
     'platex': {
         'latex_engine': 'platex',
-        'geometry': ('\\usepackage[margin=1in,marginparwidth=0.5in,dvipdfm]'
-                     '{geometry}'),
+        'geometry':     '\\usepackage[dvipdfm]{geometry}',
     },
 }
 
@@ -384,12 +382,15 @@ class LaTeXTranslator(nodes.NodeVisitor):
         self.elements.update({
             'wrapperclass': self.format_docclass(document.settings.docclass),
             # if empty, the title is set to the first section title
-            'title':        document.settings.title,
-            'release':      builder.config.release,
-            'author':       document.settings.author,
-            'releasename':  _('Release'),
+            'title':        document.settings.title,    # treat as a raw LaTeX code
+            'release':      self.encode(builder.config.release),
+            'author':       document.settings.author,   # treat as a raw LaTeX code
             'indexname':    _('Index'),
         })
+        if not self.elements['releasename']:
+            self.elements.update({
+                'releasename':  _('Release'),
+            })
         if not builder.config.latex_keep_old_macro_names:
             self.elements['sphinxpkgoptions'] = 'dontkeepoldnames'
         if document.settings.docclass == 'howto':
